<?php

namespace Kylin\Excel\Concerns;

/**
 * 分块读取接口
 * 
 * 实现此接口的导入类可以启用分块读取功能
 * 适用于大数据量导入，可以减少内存占用
 */
interface WithChunkReading
{
    /**
     * 获取分块大小
     * 
     * 返回每次读取的行数
     * 
     * @return int 分块大小（行数）
     * 
     * @example
     * public function chunkSize(): int
     * {
     *     return 1000; // 每次读取1000行
     * }
     */
    public function chunkSize(): int;
}
