<?php

namespace Kylin\Excel\Events;

/**
 * 工作表处理前事件
 * 
 * 在处理每个工作表之前触发
 * 可用于设置工作表级别的配置或初始化
 */
class BeforeSheet extends Event
{
    /**
     * 获取事件名称
     * 
     * @return string 事件名称
     */
    public function getName(): string
    {
        return 'BeforeSheet';
    }
}
