<?php

namespace Kylin\Excel\Concerns;

/**
 * 集合导入接口
 * 
 * 实现此接口的导入类可以接收Excel数据作为Laravel Collection
 * 所有数据会一次性传递给collection方法
 */
interface ToCollection
{
    /**
     * 处理导入数据
     * 
     * 接收Excel文件中的所有数据作为集合
     * 
     * @param iterable $rows Excel数据集合
     * @return void
     * 
     * @example
     * public function collection(iterable $rows): void
     * {
     *     foreach ($rows as $row) {
     *         // 处理每行数据
     *     }
     * }
     */
    public function collection(iterable $rows): void;
}
