<?php

namespace Kylin\Excel\Events;

/**
 * 工作表处理后事件
 * 
 * 在处理每个工作表之后触发
 * 可用于执行工作表级别的清理或汇总操作
 */
class AfterSheet extends Event
{
    /**
     * 获取事件名称
     * 
     * @return string 事件名称
     */
    public function getName(): string
    {
        return 'AfterSheet';
    }
}
