<?php

namespace Kylin\Excel\Events;

/**
 * 导入前事件
 * 
 * 在Excel导入开始之前触发
 * 可用于设置导入前的准备工作，如验证文件、设置初始状态等
 */
class BeforeImport extends Event
{
    /**
     * 获取事件名称
     * 
     * @return string 事件名称
     */
    public function getName(): string
    {
        return 'BeforeImport';
    }
}
