<?php

namespace Kylin\Excel\Concerns;

/**
 * 集合数据源接口
 * 
 * 实现此接口的导出类可以从Laravel Collection获取导出数据
 * 适用于数据量较小或已在内存中的数据导出
 */
interface FromCollection
{
    /**
     * 获取导出数据集合
     * 
     * 返回包含导出数据的可迭代对象
     * 
     * @return iterable 导出数据集合
     * 
     * @example
     * public function collection(): iterable
     * {
     *     return User::all();
     * }
     */
    public function collection(): iterable;
}
