<?php

namespace Kylin\Excel\Concerns;

/**
 * 数组数据源接口
 * 
 * 实现此接口的导出类可以从数组获取导出数据
 * 适用于数据已组织为数组的情况
 */
interface FromArray
{
    /**
     * 获取导出数据数组
     * 
     * 返回包含导出数据的数组
     * 
     * @return array 导出数据数组
     * 
     * @example
     * public function array(): array
     * {
     *     return [
     *         ['张三', 'zhangsan@example.com'],
     *         ['李四', 'lisi@example.com'],
     *     ];
     * }
     */
    public function array(): array;
}
