<?php

namespace Kylin\Excel\Concerns;

/**
 * 工作表标题接口
 * 
 * 实现此接口的导出类可以定义工作表的标题
 * 工作表标题将显示在Excel底部的标签页上
 */
interface WithTitle
{
    /**
     * 获取工作表标题
     * 
     * 返回工作表的标题名称
     * 
     * @return string 工作表标题
     * 
     * @example
     * public function title(): string
     * {
     *     return '用户数据';
     * }
     */
    public function title(): string;
}
