<?php

namespace Kylin\Excel\Concerns;

/**
 * 标题行接口
 * 
 * 实现此接口的导出类可以定义Excel文件的标题行
 * 标题行将显示在Excel文件的第一行
 */
interface WithHeadings
{
    /**
     * 获取标题行
     * 
     * 返回标题行数组，每个元素对应一列的标题
     * 
     * @return array 标题行数组
     * 
     * @example
     * public function headings(): array
     * {
     *     return ['姓名', '邮箱', '电话'];
     * }
     */
    public function headings(): array;
}
