<?php

namespace Kylin\Excel\Events;

/**
 * 导入后事件
 * 
 * 在Excel导入完成之后触发
 * 可用于执行导入后的处理工作，如发送通知、更新缓存等
 */
class AfterImport extends Event
{
    /**
     * 获取事件名称
     * 
     * @return string 事件名称
     */
    public function getName(): string
    {
        return 'AfterImport';
    }
}
