<?php

namespace Kylin\Excel\Concerns;

/**
 * 自定义起始单元格接口
 * 
 * 实现此接口的导出类可以指定数据写入的起始位置
 * 默认从A1单元格开始写入
 */
interface WithCustomStartCell
{
    /**
     * 获取起始单元格
     * 
     * 返回数据写入的起始单元格坐标
     * 
     * @return string 单元格坐标（如'A1'、'B2'等）
     * 
     * @example
     * public function startCell(): string
     * {
     *     return 'B3'; // 从B3单元格开始写入
     * }
     */
    public function startCell(): string;
}
