<?php

namespace Kylin\Excel\Concerns;

/**
 * 列格式化接口
 * 
 * 实现此接口的导出类可以为指定列设置数字格式
 * 如日期格式、货币格式、百分比格式等
 */
interface WithColumnFormatting
{
    /**
     * 获取列格式化配置
     * 
     * 返回列格式化数组，键为列字母，值为格式代码
     * 
     * @return array 列格式化配置
     * 
     * @example
     * public function columnFormats(): array
     * {
     *     return [
     *         'A' => NumberFormat::FORMAT_DATE_YYYYMMDD,
     *         'B' => NumberFormat::FORMAT_CURRENCY_USD_SIMPLE,
     *         'C' => NumberFormat::FORMAT_PERCENTAGE_00,
     *     ];
     * }
     */
    public function columnFormats(): array;
}
