<?php

namespace Kylin\Excel\Events;

/**
 * 导入失败事件
 * 
 * 在Excel导入过程中发生异常时触发
 * 可用于记录错误日志、发送错误通知等
 */
class ImportFailed extends Event
{
    /**
     * 构造函数
     * 
     * @param object $concernable 关联的导入对象
     * @param \Throwable $exception 发生的异常
     */
    public function __construct(
        object $concernable,
        protected \Throwable $exception,
    ) {
        parent::__construct($concernable);
    }

    /**
     * 获取事件名称
     * 
     * @return string 事件名称
     */
    public function getName(): string
    {
        return 'ImportFailed';
    }

    /**
     * 获取异常对象
     * 
     * 返回导致导入失败的异常实例
     * 
     * @return \Throwable 异常对象
     */
    public function getException(): \Throwable
    {
        return $this->exception;
    }
}
