<?php

namespace Kylin\Excel\Concerns;

/**
 * 数组导入接口
 * 
 * 实现此接口的导入类可以接收Excel数据作为数组
 * 所有数据会一次性传递给array方法
 */
interface ToArray
{
    /**
     * 处理导入数据
     * 
     * 接收Excel文件中的所有数据
     * 
     * @param array $rows Excel数据数组，每个元素为一行
     * @return void
     * 
     * @example
     * public function array(array $rows): void
     * {
     *     foreach ($rows as $row) {
     *         // 处理每行数据
     *     }
     * }
     */
    public function array(array $rows): void;
}
