<?php

namespace Kylin\Excel\Concerns;

/**
 * 多工作表接口
 * 
 * 实现此接口的导出类可以导出包含多个工作表的Excel文件
 * 每个工作表由单独的导出对象处理
 */
interface WithMultipleSheets
{
    /**
     * 获取工作表数组
     * 
     * 返回包含多个工作表导出对象的数组
     * 
     * @return array 工作表导出对象数组
     * 
     * @example
     * public function sheets(): array
     * {
     *     return [
     *         new UsersExport(),
     *         new OrdersExport(),
     *     ];
     * }
     */
    public function sheets(): array;
}
