<?php

namespace Kylin\Excel\Events;

/**
 * 导出后事件
 * 
 * 在Excel导出完成之后触发
 * 可用于执行导出后的清理工作，如发送通知、记录日志等
 */
class AfterExport extends Event
{
    /**
     * 获取事件名称
     * 
     * @return string 事件名称
     */
    public function getName(): string
    {
        return 'AfterExport';
    }
}
